pub struct Index {
pub unique: bool,
pub using: Option<Using>,
pub default_opclass: Option<OpClass>,
pub with: Option<With>,
/* private fields */
}Expand description
Can appear on columns, scalars, and tables.
Indexed with the same name are merged, if one index is marked as unique, and other isn’t - raises a validation error.
Fields
unique: boolusing: Option<Using>default_opclass: Option<OpClass>with: Option<With>Implementations
Sourceimpl Index
impl Index
pub fn new( name: Option<DbIdent<IndexKind>>, unique: bool, fields: Vec<(ColumnIdent, Option<OpClass>)>, using: Option<Using>, default_opclass: Option<OpClass>, with: Option<With>, ) -> Self
pub fn propagate_to_table(self, column: ColumnIdent) -> Self
pub fn fields(&self) -> &[(ColumnIdent, Option<OpClass>)]
pub fn field_idents(&self) -> impl IntoIterator<Item = ColumnIdent> + '_
pub fn clone_for_propagate(&self) -> Self