pub struct PrimaryKey {
pub columns: Vec<ColumnIdent>,
/* private fields */
}Expand description
Can appear on columns, scalars, and tables.
Only tables can define name for primary key, in other cases it will raise a validation error. Always merged, if there is a name conflict - raises a validation error. When appears on a scalar - always inlined to column.
Fields
columns: Vec<ColumnIdent>Implementations
Sourceimpl PrimaryKey
impl PrimaryKey
pub fn new( name: Option<DbIdent<ConstraintKind>>, columns: Vec<ColumnIdent>, ) -> Self
pub fn propagate_to_table(self, column: ColumnIdent) -> Self
pub fn clone_for_propagate(&self) -> Self