Module process

Module process 

Structs

Pgnc

Enums

NamingConvention

Functions

check_unique_identifiers
Basic check if there is any definition with duplicate identifier Database identifiers are not checked here, because they might be only available after naming convention processing, and there is some variance between different database implementations. E.g some databases allow domain and table types to be conflicting, and some not, there is different behavior for truncation, there might be forbidden system tables, and so on. Identifiers are unique to immigrant, so checking of them is trivial.
check_unique_in_composite
check_unique_in_enum
check_unique_in_table
check_unique_mixin_identifiers