pub fn check_unique_identifiers(schema: &Schema, diagnostics: &mut Report)Expand description
Basic check if there is any definition with duplicate identifier Database identifiers are not checked here, because they might be only available after naming convention processing, and there is some variance between different database implementations. E.g some databases allow domain and table types to be conflicting, and some not, there is different behavior for truncation, there might be forbidden system tables, and so on. Identifiers are unique to immigrant, so checking of them is trivial.