Pgnc

Struct Pgnc 

pub struct Pgnc<T>(pub T);

Tuple Fields

0: T

Implementations

Source

impl Pgnc<&mut Schema>

pub fn process_naming(&mut self, rn: &mut RenameMap)

Source

impl Pgnc<&mut Scalar>

First generate names, because only check constraint are mergeable, and there is no problem with merging unrelated constraints, then merge constraints with the same name.

pub fn generate_name(&self, rn: &mut RenameMap)

Generate name for the scalar itself

pub fn generate_names(&mut self, rn: &mut RenameMap)

In postgres, first check constraint has autogenerated table_check name, second is table_check1 and so on. In immigrant, constraints with the same name are merged, so only name we should save to every constraint is table_check

pub fn merge_checks(&mut self, rn: &RenameMap)

All checks with the same name are merged using AND

Source

impl Pgnc<&mut Table>

First merge constraints, to allow specifying partial primary keys, i.e

a @primary_key;
b @primary_key;
c @primary_key;

Should be equivalent to

a;
b;
c;
@primary_key(a, b, c)

Then generate names, i.e for the specified example it will be table_a_b_c_pk

pub fn generate_name(&self, rn: &mut RenameMap)

Generate name for the table itself

pub fn generate_column_names(&self, rn: &mut RenameMap)

pub fn merge(&mut self, rn: &RenameMap)

Merge annotations:

  • Primary keys are always merged, it is assumed at most only name will be set. TODO: It gets weird in presence of mixins, e.g mixin can add another primary key, how that should be handled?
  • Checks with the same name (+all unnamed) are merged using AND
  • Unique constraints are merged the same way as the primary key, but unnamed uniques are not merged
  • Indexes are merged the same way as unique constraints, except accounting for the uniqueness flag
pub fn generate_names(&mut self, rn: &mut RenameMap)

Source

impl Pgnc<&mut View>

pub fn generate_name(&self, rn: &mut RenameMap)

Generate name for the table itself