pub struct SchemaProcessOptions {
pub generator_supports_domain: bool,
pub naming_convention: NamingConvention,
}Fields
generator_supports_domain: boolIf not - then every scalar is transformed to a regular type by inlining.
naming_convention: NamingConventionHow to create item names, how annotation deduplication should be handled, etc.