TableItem

Struct TableItem 

pub struct TableItem<'a, I> {
    pub table: SchemaTable<'a>,
    pub value: &'a I,
}

Fields

table: SchemaTable<'a>value: &'a I

Implementations

Source

impl<'a> TableItem<'a, Column>

pub fn db_type(&self, rn: &RenameMap, report: &mut Report) -> DbNativeType

pub fn ty(&'a self) -> SchemaType<'a>

pub fn default(&self) -> Option<&Sql>

Only returns column default, if the underlying type has default value - it needs to be handled manually. If you only want to check if default exists - use has_default.

pub fn initialize_as(&self) -> Option<&Sql>

pub fn is_pk_part(&self) -> bool

pub fn has_default(&self) -> bool

pub fn is_pk_full(&self) -> bool

Source

impl TableItem<'_, Index>

pub fn db_columns<'i>( &'i self, rn: &'i RenameMap, ) -> impl Iterator<Item = DbColumn> + 'i

pub fn db_columns_opclass<'i>( &'i self, rn: &'i RenameMap, ) -> impl Iterator<Item = (DbColumn, Option<OpClass>)> + 'i

pub fn db_types<'i>( &'i self, rn: &'i RenameMap, report: &'i mut Report, ) -> impl Iterator<Item = DbNativeType> + 'i

Source

impl<'s> TableItem<'s, ForeignKey>

Source

impl<'a, I> TableItem<'a, I>

pub fn unchecked_new(table: SchemaTable<'a>, value: &'a I) -> Self