TableColumn

Type Alias TableColumn 

pub type TableColumn<'a> = TableItem<'a, Column>;

Aliased Type

pub struct TableColumn<'a> {
    pub table: SchemaTable<'a>,
    pub value: &'a Column,
}

Fields

table: SchemaTable<'a>value: &'a Column

Implementations

Source

impl<'a> TableColumn<'a>

pub fn db_type(&self, rn: &RenameMap, report: &mut Report) -> DbNativeType

pub fn ty(&'a self) -> SchemaType<'a>

pub fn default(&self) -> Option<&Sql>

Only returns column default, if the underlying type has default value - it needs to be handled manually. If you only want to check if default exists - use has_default.

pub fn initialize_as(&self) -> Option<&Sql>

pub fn is_pk_part(&self) -> bool

pub fn has_default(&self) -> bool

pub fn is_pk_full(&self) -> bool