Module uid

Module uid 

Structs

OwnUid
OwnUid - Uid attached to annotation/something else It doesn’t make sense to clone Annotation Uid, because if we do so, then changing name of annotation on table column also changes annotation name in scalar/other copies of this annotation Because of that, cloning of OwnUid should also clone entry of RenameMap.
RenameMap
Uid

Traits

HasUid
RenameExt