pub struct TableItem<'a, I> {
pub table: SchemaTable<'a>,
pub value: &'a I,
}Fields
table: SchemaTable<'a>value: &'a IImplementations
Sourceimpl<'a> TableItem<'a, Column>
impl<'a> TableItem<'a, Column>
pub fn db_type(&self, rn: &RenameMap, report: &mut Report) -> DbNativeType
pub fn ty(&'a self) -> SchemaType<'a>
Sourcepub fn default(&self) -> Option<&Sql>
pub fn default(&self) -> Option<&Sql>
Only returns column default, if the underlying type has default value - it needs to be handled manually. If you only want to check if default exists - use has_default.
pub fn initialize_as(&self) -> Option<&Sql>
pub fn is_pk_part(&self) -> bool
pub fn has_default(&self) -> bool
pub fn is_pk_full(&self) -> bool
Sourceimpl TableItem<'_, Index>
impl TableItem<'_, Index>
pub fn db_columns<'i>( &'i self, rn: &'i RenameMap, ) -> impl Iterator<Item = DbColumn> + 'i
pub fn db_columns_opclass<'i>( &'i self, rn: &'i RenameMap, ) -> impl Iterator<Item = (DbColumn, Option<OpClass>)> + 'i
pub fn db_types<'i>( &'i self, rn: &'i RenameMap, report: &'i mut Report, ) -> impl Iterator<Item = DbNativeType> + 'i
Sourceimpl<'s> TableItem<'s, ForeignKey>
impl<'s> TableItem<'s, ForeignKey>
pub fn source_columns(&self) -> Vec<ColumnIdent> ⓘ
pub fn target_columns(&self) -> Vec<ColumnIdent> ⓘ
pub fn target_table(&self) -> SchemaTable<'s>
pub fn source_db_columns(&self, rn: &RenameMap) -> Vec<DbColumn> ⓘ
pub fn target_db_columns(&self, rn: &RenameMap) -> Vec<DbColumn> ⓘ
pub fn db_types(&self, rn: &RenameMap, report: &mut Report) -> Vec<DbNativeType> ⓘ
pub fn cardinality(&self) -> (Cardinality, Cardinality)
Sourceimpl<'a, I> TableItem<'a, I>
impl<'a, I> TableItem<'a, I>
pub fn unchecked_new(table: SchemaTable<'a>, value: &'a I) -> Self